@@ -242,8 +242,13 @@ translate_compoundInput <- function(data, session, name){
     meta <- as.list(default_val$meta)
   }
 
+  # session_scope = character(0)
+  # if( !mis_sess ){
+  #   session_scope = session$ns(NULL)
+  # }
+
   inner_ids <- names(meta$bind_infos)
-  update_functions <- sapply(inner_ids, function(id){
+  update_functions <- sapply(inner_ids, function(id, ...){
     bind_info <- meta$bind_infos[[id]]
     if(is.list(bind_info) && 'update_function' %in% names(bind_info)){
       update_function <- bind_info$update_function
@@ -251,23 +256,64 @@ translate_compoundInput <- function(data, session, name){
         update_function <- str2lang(update_function[[1]])
         input_names <- names(formals(eval(update_function)))
 
-        f <- function(ii, ...){
-          if(mis_sess){
-            session <- shiny::getDefaultReactiveDomain()
+        # in case R says ii not found when checking
+        ii <- NULL
+        .session <- NULL
+        fbody <- rlang::quo({
+          session_scope <- .session$ns(NULL)
+          session <- .session
+          widget_name <- !!name
+          if((length(session_scope) == 1) && session_scope != ''){
+            # check whether name starts with session_scope if yes, this means
+            # we register submodule in root session,
+            # and we need to go back and remove session_scope in name
+            slen <- stringr::str_length(session_scope)
+            nlen <- stringr::str_length(widget_name)
+            if( slen < nlen - 1 ){
+              if( stringr::str_sub(widget_name, end = slen + 1) == sprintf('%s-', session_scope) ){
+                # need to remove scope from widget_name
+                widget_name <- stringr::str_sub(widget_name, start = slen + 2)
+              }
+            }
           }
-          inputId <- sprintf('%s_%s_%s', name, id, ii)
-          call <- as.call(list(update_function, session = quote(session),
+
+          inputId <- sprintf('%s_%s_%s', widget_name, !!id, ii)
+          call <- as.call(list(!!update_function, session = quote(session),
                                inputId = inputId, ...))
-          if( !'...' %in% input_names){
+          if( !'...' %in% !!input_names){
             # Need to match call
             nms <- names(call)
-            sel <- nms %in% c('', input_names)
+            sel <- nms %in% c('', !!input_names)
             if(!all(sel)){
               call <- call[sel]
             }
           }
-          eval(call)
+          re <- eval(call)
+          # clean up in case of large memory leak?
+          rm(session)
+          re
+        })
+
+        f <- function(ii, ..., .session = shiny::getDefaultReactiveDomain()){
+          # if(mis_sess){
+          #   session <- shiny::getDefaultReactiveDomain()
+          # }
+          # inputId <- sprintf('%s_%s_%s', name, id, ii)
+          # call <- as.call(list(update_function, session = quote(session),
+          #                      inputId = inputId, ...))
+          # if( !'...' %in% input_names){
+          #   # Need to match call
+          #   nms <- names(call)
+          #   sel <- nms %in% c('', input_names)
+          #   if(!all(sel)){
+          #     call <- call[sel]
+          #   }
+          # }
+          # eval(call)
         }
+
+        body(f) <- rlang::quo_squash(fbody)
+        environment(f) <- baseenv()
         return( f )
       }
     }
